@@ -19,9 +19,11 @@ package org.gradle.process.internal.worker.problem;
 import org.gradle.api.NonNullApi;
 import org.gradle.api.problems.internal.Problem;
 import org.gradle.api.problems.internal.ProblemEmitter;
+import org.gradle.api.problems.internal.ProblemSummarizer;
 import org.gradle.internal.operations.OperationIdentifier;
 
 import javax.annotation.Nullable;
+import java.io.File;
 
 /**
  * Worker-side implementation of {@link ProblemEmitter}.
@@ -29,7 +31,7 @@ import javax.annotation.Nullable;
  * This emitter will use the {@link WorkerProblemProtocol} to communicate problems to the daemon.
  */
 @NonNullApi
-public class WorkerProblemEmitter implements ProblemEmitter {
+public class WorkerProblemEmitter implements ProblemSummarizer {
     private final WorkerProblemProtocol protocol;
 
     public WorkerProblemEmitter(WorkerProblemProtocol protocol) {
@@ -40,4 +42,14 @@ public class WorkerProblemEmitter implements ProblemEmitter {
     public void emit(Problem problem, @Nullable OperationIdentifier id) {
         protocol.reportProblem(problem, id);
     }
+
+    @Override
+    public String getId() {
+        return "";
+    }
+
+    @Override
+    public void report(File reportDir, ProblemConsumer validationFailures) {
+        //no op
+    }
 }
